@@ -1,13 +1,17 @@
 //! Value types accepted by leaf query clauses
 
+mod coordinate;
 mod geo_point;
 mod number;
-mod scalar;
 mod search;
+mod term;
+mod text;
 mod units;
 
+pub use self::coordinate::*;
 pub use self::geo_point::*;
 pub use self::number::*;
-pub use self::scalar::*;
 pub use self::search::*;
+pub use self::term::*;
+pub use self::text::*;
 pub use self::units::*;
