@@ -26,7 +26,7 @@ pub struct QueryStringQuery {
 #[derive(Debug, Clone, PartialEq, Serialize, Default)]
 struct Inner {
     #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
-    query: String,
+    query: Text,
 
     #[serde(skip_serializing_if = "ShouldSkip::should_skip")]
     default_field: Option<String>,
@@ -102,7 +102,7 @@ impl Query {
     /// [Simple query string syntax](https://www.elastic.co/guide/en/elasticsearch/reference/current/query-dsl-simple-query-string-query.html#simple-query-string-syntax).
     pub fn query_string<S>(query: S) -> QueryStringQuery
     where
-        S: Into<String>,
+        S: Into<Text>,
     {
         QueryStringQuery {
             inner: Inner {
