@@ -95,8 +95,8 @@ query!(Query {
     Wildcard(WildcardQuery),
     TermsSet(TermsSetQuery),
     Term(TermQuery),
-    TermsValues(TermsQuery<std::collections::BTreeSet<crate::Scalar>>),
-    TermsLookup(TermsQuery<self::params::TermsLookup>),
+    Terms(TermsQuery),
+    TermsLookup(TermsLookupQuery),
     Exists(ExistsQuery),
     Range(RangeQuery),
     Ids(IdsQuery),
@@ -113,9 +113,9 @@ query!(Query {
     Nested(NestedQuery),
     Boosting(BoostingQuery),
     DisMax(DisMaxQuery),
-    PercolateDocument(PercolateQuery<serde_json::Value>),
-    PercolateDocuments(PercolateQuery<Vec<serde_json::Value>>),
-    PercolateLookup(PercolateQuery<self::params::PercolateLookup>),
+    Pinned(PinnedQuery),
+    Percolate(PercolateQuery),
+    PercolateLookup(PercolateLookupQuery),
     FunctionScore(FunctionScoreQuery),
     RankFeature(RankFeatureQuery),
     RankFeatureSaturation(RankFeatureSaturationQuery),
