@@ -17,8 +17,10 @@ mod geo_query;
 mod multi_match_query;
 mod nested_query;
 mod percolate_query;
+mod pinned_query;
 mod range_query;
 mod regexp_query;
+mod shape_query;
 mod simple_query_string_query;
 mod terms_query;
 mod terms_set_query;
@@ -35,9 +37,11 @@ pub use self::negative_boost::*;
 pub use self::nested_query::*;
 pub use self::operator::*;
 pub use self::percolate_query::*;
+pub use self::pinned_query::*;
 pub use self::range_query::*;
 pub use self::regexp_query::*;
 pub use self::rewrite::*;
+pub use self::shape_query::*;
 pub use self::simple_query_string_query::*;
 pub use self::terms_query::*;
 pub use self::terms_set_query::*;
